@@ -3,7 +3,7 @@ from __future__ import annotations
 from importlib.metadata import version
 
 import pytest
-from spotify_tracks_archiver import constants
+from spotify_tracks_archiver import constants as C
 from spotify_tracks_archiver import main
 
 
@@ -22,16 +22,27 @@ def test_version(capsys):
 
     out, err = capsys.readouterr()
     assert out.strip(
-    ) == f'{constants.app_name} {version(constants.app_name)}'
+    ) == f'{C.app_name} {version(C.app_name)}'
     assert not err
 
 
 def test_dry_run():
     assert main.run_cli(
         ['--dry-run'],
+    ) == 0
+
+
+def test_unchanged_env_detection():
+    """For when someone forgets to update .env after copying the example."""
+    assert main.run_cli(
+        config={
+            'CLIENT_ID': '...',
+            'CLIENT_SECRET': 'client_secret',
+        },
+    ) == 2
+    assert main.run_cli(
         config={
             'CLIENT_ID': 'client_id',
-            'CLIENT_SECRET': 'client_secret',
-            'REFRESH_TOKEN': 'refresh_token',
+            'CLIENT_SECRET': '...',
         },
-    ) == 0
+    ) == 2
